MATLAB Compatibility Module
***************************

.. automodule:: matlab
    :members:
    
.. todo:: 
    The following functions should be documented in their own modules!
    This is only a temporary solution.

.. autofunction:: pzmap.pzmap
.. autofunction:: freqplot.nyquist
.. autofunction:: nichols.nichols
.. autofunction:: statefbk.place
.. autofunction:: statefbk.lqr
.. autofunction:: statefbk.ctrb
.. autofunction:: statefbk.obsv
.. autofunction:: statefbk.gram
.. autofunction:: delay.pade
.. autofunction:: freqplot.gangof4
.. autofunction:: ctrlutil.unwrap
.. autofunction:: mateqn.lyap
.. autofunction:: mateqn.dlyap
.. autofunction:: mateqn.care
.. autofunction:: mateqn.dare
